# pyspades flavoured enet library

This is upstream `pyenet` + `enet-1.3.3` with pyspades patches on top of it

`pyenet` can be found here: https://github.com/aresch/pyenet
`enet-1.3.3` can be found here: http://enet.bespin.org/ (see direct link in the source code)

`pyenet` is meant to be updated to upstream version. Potentially subject to be split into separate package.